#
# spec file for package Rivet
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_name lib%{name}-2_5_2

Name:           Rivet
Version:        2.5.2
Release:        1.3
Summary:        A toolkit for validation of Monte Carlo event generators
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://rivet.hepforge.org/
Source:         http://www.hepforge.org/archive/rivet/%{name}-%{version}.tar.bz2
Patch1:         sover.diff
BuildRequires:  HepMC-devel
BuildRequires:  YODA-devel >= 1.0.6
BuildRequires:  autoconf
BuildRequires:  automake
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  doxygen
BuildRequires:  fastjet-devel
BuildRequires:  fastjet-plugin-siscone-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  texlive-latex-bin
BuildRequires:  yaml-cpp-devel
BuildRequires:  pkgconfig(gsl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Rivet project (Robust Independent Validation of Experiment and
Theory) is a toolkit for validation of Monte Carlo event generators.
It provides a large (and ever growing) set of experimental analyses
useful for MC generator development, validation, and tuning, as well
as a convenient infrastructure for adding your own analyses. Rivet is
the most widespread way by which analysis code from the LHC and other
high-energy collider experiments is preserved for comparison to and
development of future theory models. 

%package -n %{so_name}
Summary:        A toolkit for validation of Monte Carlo event generators
Group:          System/Libraries

%description -n %{so_name}
The Rivet project (Robust Independent Validation of Experiment and
Theory) is a toolkit for validation of Monte Carlo event generators.
It provides a large (and ever growing) set of experimental analyses
useful for MC generator development, validation, and tuning, as well
as a convenient infrastructure for adding your own analyses. Rivet is
the most widespread way by which analysis code from the LHC and other
high-energy collider experiments is preserved for comparison to and
development of future theory models. 

This package provides the shared libraries for %{name}.

%package devel
Summary:        A toolkit for validation of Monte Carlo event generators
Group:          Development/Libraries/C and C++
Requires:       %{so_name} = %{version}

%description devel
The Rivet project (Robust Independent Validation of Experiment and
Theory) is a toolkit for validation of Monte Carlo event generators.
It provides a large (and ever growing) set of experimental analyses
useful for MC generator development, validation, and tuning, as well
as a convenient infrastructure for adding your own analyses. Rivet is
the most widespread way by which analysis code from the LHC and other
high-energy collider experiments is preserved for comparison to and
development of future theory models. 

This package provides the source files for development with %{name}.

%package -n python-%{name}
Summary:        A toolkit for validation of Monte Carlo event generators
Group:          Development/Languages/Python
Requires:       %{so_name} = %{version}

%description -n python-%{name}
The Rivet project (Robust Independent Validation of Experiment and
Theory) is a toolkit for validation of Monte Carlo event generators.
It provides a large (and ever growing) set of experimental analyses
useful for MC generator development, validation, and tuning, as well
as a convenient infrastructure for adding your own analyses. Rivet is
the most widespread way by which analysis code from the LHC and other
high-energy collider experiments is preserved for comparison to and
development of future theory models. 

This package provides the python bindings for %{name}.

%prep
%setup -q
%patch -P 1 -p1

# REMOVE EXISTING rivet.pc FILE, ALLOW make TO GENERATE rivet.pc FROM rivet.pc.in
rm -f rivet.pc

# REMOVE INCORRECT LIBDIRS FROM .pc.in FILE (the right libdirs are already present)
sed -i "s| -L@GSLLIBPATH@||g" rivet.pc.in

%build
autoreconf -fi
%configure --docdir=%{_docdir}/%{name}/
make %{?_smp_mflags} pkglibdir="%{_libdir}/rivet-%{version}"

%install
%make_install pkglibdir="%{_libdir}/rivet-%{version}"

# Remove traces of BUILDROOT from files
sed -i "s|%{buildroot}||g" %{buildroot}%{python_sitearch}/rivet/*.pyc

# MANUALLY REMOVE rpath FROM PKGCONFIG FILE AND rivet-config SCRIPT
sed -i "s|-Wl,-rpath,||g" %{buildroot}%{_libdir}/pkgconfig/rivet.pc
sed -i "s|-Wl,-rpath,||g" %{buildroot}%{_bindir}/rivet-config

find %{buildroot}%{_libdir}/ -name "*.la" -delete

%post -n %{so_name} -p /sbin/ldconfig

%postun -n %{so_name} -p /sbin/ldconfig

%files -n %{so_name}
%defattr(-,root,root)
%{_libdir}/libRivet-*.so
%{_libdir}/rivet-%{version}/

%files devel
%defattr(-,root,root)
%doc AUTHORS ChangeLog README COPYING
%{_bindir}/rivet-config
%{_bindir}/rivet-buildplugin
%{_includedir}/%{name}/
%{_datadir}/%{name}/
%{_libdir}/libRivet.so
%{_libdir}/pkgconfig/rivet.pc

%files -n python-%{name}
%defattr(-,root,root)
%{_bindir}/*
%exclude %{_bindir}/rivet-config
%exclude %{_bindir}/rivet-buildplugin
%{python_sitearch}/rivet/
%{python_sitearch}/rivet-*egg-info

%changelog
* Mon Feb 13 2017 jengelh@inai.de
- Add sover.diff, enforce versioning as per guidelines
* Tue Feb  7 2017 jengelh@inai.de
- Correct RPM groups
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 2.5.2:
  * Add a requirement to DressedLeptons that the FinalState passed
    as 'bareleptons' will be filtered to only contain charged
    leptons, if that is not already the case. Thanks to Markus
    Seidel for the suggestion.
  * Add Simone Amoroso's plugin for hadron spectra
    (ALEPH_1995_I382179)
  * Add Simone Amoroso's plugin for hadron spectra
    (OPAL_1993_I342766)
  * Add CMS ttbar analysis from contrib, mark validated
    (CMS_2016_I1473674)
  * Extend rivet-mkhtml --booklet to also work with pdfmerge
  * Fix make-plots automatic YMax calculation, which had a typo
    from code cleaning (mea culpa!).
  * Fix ChargedLeptons projection, which failed to exclude
    neutrinos!!! Thanks to Markus Seidel.
  * Add templated FN filtering arg versions of the Jet::*Tags()
    and Jet::*Tagged() functions.
  * Add CMS partonic top analysis (CMS_2015_I1397174)
  * Add L3 xp analysis of eta mesons, thanks Simone
    (L3_1992_I336180)
  * Add D0 1.8 TeV jet shapes analysis, thanks Simone
    (D0_1995_I398175)
  * Add has{Ancestor,Parent,Child,Descendant}With functions and
    HasParticle{Ancestor,Parent,Child,Descendant}With functors.
  * Add ATLAS 8TeV ttbar analysis from contrib
    (ATLAS_2015_I1404878)
  * Add particles(GenParticlePtr) to RivetHepMC.hh
  * Add hasParent, hasParentWith, and hasAncestorWith to Particle.
  * Add ATLAS 8TeV dijet analysis from contrib
    (ATLAS_2015_I1393758)
  * Add ATLAS 8TeV 'number of tracks in jets' analysis from
    contrib (ATLAS_2016_I1419070)
  * Add ATLAS 8TeV g->H->WW->enumunu analysis from contrib
    (ATLAS_2016_I1444991)
  * Explicit std::toupper and std::tolower to make clang happy
  * Add ATLAS Run 2 0-lepton SUSY and monojet search papers
    (ATLAS_2016_I1452559, ATLAS_2016_I1458270)
  * Add experimental Cutflow and Cutflows objects for BSM cut
    tracking.
  * Add 'direct' versions of any, all, none to Utils.hh, with an
    implicity bool() transforming function.
  * Add and mark validated B+ to omega analysis
    (BABAR_2013_I1116411)
  * Add and mark validated D0 to pi- analysis
    (BABAR_2015_I1334693)
  * Add a few more particle names and use PID names in recently
    added analyses
  * Add Simone's OPAL b-frag analysis (OPAL_2003_I599181) after
    some cleanup and heavy usage of new features
  * Restructured DELPHI_2011_I890503 in the same manner --- picks
    up a few more B-hadrons now (e.g. 20523 and such)
  * Clean up and add ATLAS 8TeV MinBias (from contrib
    ATLAS_2016_I1426695)
  * Add a static constexpr DBL_NAN to Utils.hh for convenience,
    and move some utils stuff out of MathHeader.hh
  * Add count function to Tools/Utils.h
  * Add and mark validated B0bar and Bminus-decay to pi analysis
    (BELLE_2013_I1238273)
  * Add and mark validated B0-decay analysis (BELLE_2011_I878990)
  * Add and mark validated B to D decay analysis
    (BELLE_2011_I878990)
  * Add C-array version of multi-target Analysis::scale() and
    normalize(), and fix (semantic) constness.
  * Add == and != operators for cuts applied to integers.
  * Add missing delta{Phi,Eta,Rap}{Gtr,Less} functors to
    ParticleBaseUtils.hh
  * Add templated functor filtering args to the Particle
    parent/child/descendent methods.
  * Add ATLAS Run 1 medium and tight electron ID efficiency
    functions.
  * Update configure scripts to use newer (Py3-safe) Python
    testing macros.
  * Add isFirstWith(out), isLastWith(out) functions, and functor
    wrappers, using Cut and templated function/functor args.
  * Add Particle::parent() method.
  * Add using import/typedef of HepMC *Ptr types (useful step for
    HepMC 2.07 and 3.00).
  * Various typo fixes (and canonical renaming) in
    ParticleBaseUtils functor collection.
  * Add ATLAS MV2c10 and MV2c20 b-tagging effs to
    SmearingFunctions.hh collection.
  * Add a PartonicTops projection.
  * Add overloaded versions of the Event::allParticles() method
    with selection Cut or templated selection function arguments.
  * Add rapidity scheme arg to DeltaR functor constructors.
  * Provide an Analysis::bookCounter(d,x,y, title) function, for
    convenience and making the mkanalysis template valid.
  * Improve container utils functions, and provide combined
    remove_if+erase filter_* functions for both select- and
    discard-type selector functions.
  * Bugfix in rivet-mkhtml (NoneType: ana.spiresID() --> spiresid)
  * Added <numeric> include to Rivet/Tools/Utils.h to make gcc6
    happy
  * Add efffilt() functions and Particle/JetEffFilt functors to
    SmearingFunctions.hh
  * Adding filterBy methods for Particle and Jet which accept
    generic boolean functions as well as the Cut specialisation.
  * Add a Jet::particles(Cut&) method, for inline filtering of jet
    constituents.
  * Add 'conjugate' behaviours to container head and tail functions
    via negative length arg values.
  * Add convenience headers for including all final-state and
    smearing projections, to save user typing.
  * Add standard MET functions for ATLAS R1 (and currently copies
    for R2 and CMS).
  * Add lots of vector/container helpers for e.g. container slicing,
    summing, and min/max calculation.
  * Adapt SmearedMET to take *two* arguments, since SET is typically
    used to calculate MET resolution.
  * Adding functors for computing vector & ParticleBase differences
    w.r.t. another vector.
  * Implemented a few more cuts in prompt photon analysis
    (CDF_1993_S2742446) but to no avail, the rise of the data towards
    larger costheta values cannot be reproduced --- maybe this is a
    candidate for more scrutiny and using the boosting machinery such that
    the c.m. cuts can be done in a non-approximate way
  * Rename CDF_2009_S8383952 to CDF_2009_I856131 due to invalid Spires
    entry.
  * Add InspireID to all analysis known by their Spires key
- Even longer list of changes for version 2.2.1 through 2.5.1; see
  ChangeLog file.
- Drop upstream incorporated or otherwise fixed patches:
  * Rivet-compatibility-with-old-boost.patch.
  * 0001-fix_YODA_Histo1D_includes.patch.
  * Rivet-boost-configure-for-GCC5.patch.
* Thu Jun 25 2015 badshah400@gmail.com
- Add Rivet-boost-configure-for-GCC5.patch to fix autoconf
  boost macros lookup with GCC5; patch taken from boost.m4
  upstream [https://github.com/tsuna/boost.m4].
* Sun Oct 26 2014 badshah400@gmail.com
- Update to version 2.2.0:
  + Mark Jet::containsBottom and Jet::containsCharm as deprecated
    methods: use the new methods. Analyses updated.
  + Add Jet::bTagged(), Jet::cTagged() and Jet::tauTagged() as
    ghost-assoc-based replacements for the 'contains' tagging methods.
  + Adding support for 1D and 3D YODA scatters, and helper methods
    for calling the efficiency, asymm and 2D histo divide functions.
  + Adding 5 new ATLAS analyses:
  - ATLAS_2011_I921594: Inclusive isolated prompt photon
    analysis with full 2010 LHC data
  - ATLAS_2013_I1263495: Inclusive isolated prompt photon
    analysis with 2011 LHC data
  - ATLAS_2014_I1279489: Measurements of electroweak production
    of dijets + $Z$ boson, and distributions sensitive to vector
    boson fusion
  - ATLAS_2014_I1282441: The differential production cross
    section of the $\phi(1020)$ meson in $\sqrt{s}=7$ TeV $pp$
    collisions measured with the ATLAS detector
  - ATLAS_2014_I1298811: Leading jet underlying event at 7 TeV
    in ATLAS
  + Adding a median(vector<NUM>) function and fixing the other stats
    functions to operate on vector<NUM> rather than vector<int>.
  + Fix wrong behaviour of LorentzTransform with a null boost
    vector
  + Add calc() methods to Hemispheres as requested, to allow it to
    be used with Jet or FourMomentum inputs outside the normal
    projection system.
  + Improvements to the particles methods on
    ParticleFinder/FinalState, in particular adding the range of
    cuts arguments cf. JetAlg (and tweaking the sorted jets
    equivalent) and returning as a copy rather than a reference if
    cut/sorted to avoid accidentally messing up the cached copy.
  + Creating ParticleFinder projection base class, and moving
    Particles-accessing methods from FinalState into it.
  + Adding basic forms of MC_ELECTRONS, MC_MUONS, and MC_TAUS
    analyses.
- Changes from 2.2.0Beta:
  + See /usr/share/doc/packages/Rivet-devel/ChangeLog for full
    list.
- Packaging changes:
  + Rebase patch 0001-fix_YODA_Histo1D_includes.patch for current
    version; includes dropping the 2nd hunk since it is already
    incorporated upstream.
* Thu Sep 25 2014 sfalken@opensuse.org
- Added 0001-fix_YODA_Histo1D_includes.patch
  fixed buildfailure due to YODA/Histo1D changing function names
  Additionally fixed buildfailure from MAXINT being defined but not used
  See https://www.hepforge.org/lists-archive/rivet/2014-September/005167.html
* Sat Jun 21 2014 badshah400@gmail.com
- Update to version 2.1.2:
  + Lots of changes since previous version (2.0.0), see
    ChangeLog file in /usr/share/doc/packages/Rivet-devel/ for a
    full list
- Packaging changes:
  + Add Rivet-compatibility-with-old-boost.patch: fix foreach
    compatibility with boost < 1.50 and make Rivet build with
    openSUSE 12.3 again
  + Now requires YODA-devel >= 1.0.6 for building
  + Package new pkgconfig file (.pc file manually stripped of
    rpaths to avoid linking issues, and an rpmlint warning)
  + Also strip rpath from rivet-config script.
* Tue Dec 10 2013 badshah400@gmail.com
- Initial version.
